/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * This code was generated by https://github.com/google/apis-client-generator/
 * (build: 2018-10-08 17:45:39 UTC)
 * on 2020-04-27 at 14:49:19 UTC 
 * Modify at your own risk.
 */

package com.google.api.services.dialogflow.v2.model;

/**
 * Represents a conversational agent.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Dialogflow API. For a detailed explanation see:
 * <a href="https://developers.google.com/api-client-library/java/google-http-java-client/json">https://developers.google.com/api-client-library/java/google-http-java-client/json</a>
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class GoogleCloudDialogflowV2Agent extends com.google.api.client.json.GenericJson {

  /**
   * Optional. API version displayed in Dialogflow console. If not specified, V2 API is assumed.
   * Clients are free to query different service endpoints for different API versions. However, bots
   * connectors and webhook calls will follow the specified API version.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String apiVersion;

  /**
   * Optional. The URI of the agent's avatar. Avatars are used throughout the Dialogflow console and
   * in the self-hosted [Web Demo](https://cloud.google.com/dialogflow/docs/integrations/web-demo)
   * integration.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String avatarUri;

  /**
   * Optional. To filter out false positive results and still get variety in matched natural
   * language inputs for your agent, you can tune the machine learning classification threshold. If
   * the returned score value is less than the threshold value, then a fallback intent will be
   * triggered or, if there are no fallback intents defined, no intent will be triggered. The score
   * values range from 0.0 (completely uncertain) to 1.0 (completely certain). If set to 0.0, the
   * default of 0.3 is used.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.Float classificationThreshold;

  /**
   * Required. The default language of the agent as a language tag. See [Language
   * Support](https://cloud.google.com/dialogflow/docs/reference/language) for a list of the
   * currently supported language codes. This field cannot be set by the `Update` method.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String defaultLanguageCode;

  /**
   * Optional. The description of this agent. The maximum length is 500 characters. If exceeded, the
   * request is rejected.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String description;

  /**
   * Required. The name of this agent.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String displayName;

  /**
   * Optional. Determines whether this agent should log conversation queries.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.Boolean enableLogging;

  /**
   * Optional. Determines how intents are detected from user queries.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String matchMode;

  /**
   * Required. The project of this agent. Format: `projects/`.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String parent;

  /**
   * Optional. The list of all languages supported by this agent (except for the
   * `default_language_code`).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<java.lang.String> supportedLanguageCodes;

  /**
   * Optional. The agent tier. If not specified, TIER_STANDARD is assumed.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String tier;

  /**
   * Required. The time zone of this agent from the [time zone database](https://www.iana.org/time-
   * zones), e.g., America/New_York, Europe/Paris.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String timeZone;

  /**
   * Optional. API version displayed in Dialogflow console. If not specified, V2 API is assumed.
   * Clients are free to query different service endpoints for different API versions. However, bots
   * connectors and webhook calls will follow the specified API version.
   * @return value or {@code null} for none
   */
  public java.lang.String getApiVersion() {
    return apiVersion;
  }

  /**
   * Optional. API version displayed in Dialogflow console. If not specified, V2 API is assumed.
   * Clients are free to query different service endpoints for different API versions. However, bots
   * connectors and webhook calls will follow the specified API version.
   * @param apiVersion apiVersion or {@code null} for none
   */
  public GoogleCloudDialogflowV2Agent setApiVersion(java.lang.String apiVersion) {
    this.apiVersion = apiVersion;
    return this;
  }

  /**
   * Optional. The URI of the agent's avatar. Avatars are used throughout the Dialogflow console and
   * in the self-hosted [Web Demo](https://cloud.google.com/dialogflow/docs/integrations/web-demo)
   * integration.
   * @return value or {@code null} for none
   */
  public java.lang.String getAvatarUri() {
    return avatarUri;
  }

  /**
   * Optional. The URI of the agent's avatar. Avatars are used throughout the Dialogflow console and
   * in the self-hosted [Web Demo](https://cloud.google.com/dialogflow/docs/integrations/web-demo)
   * integration.
   * @param avatarUri avatarUri or {@code null} for none
   */
  public GoogleCloudDialogflowV2Agent setAvatarUri(java.lang.String avatarUri) {
    this.avatarUri = avatarUri;
    return this;
  }

  /**
   * Optional. To filter out false positive results and still get variety in matched natural
   * language inputs for your agent, you can tune the machine learning classification threshold. If
   * the returned score value is less than the threshold value, then a fallback intent will be
   * triggered or, if there are no fallback intents defined, no intent will be triggered. The score
   * values range from 0.0 (completely uncertain) to 1.0 (completely certain). If set to 0.0, the
   * default of 0.3 is used.
   * @return value or {@code null} for none
   */
  public java.lang.Float getClassificationThreshold() {
    return classificationThreshold;
  }

  /**
   * Optional. To filter out false positive results and still get variety in matched natural
   * language inputs for your agent, you can tune the machine learning classification threshold. If
   * the returned score value is less than the threshold value, then a fallback intent will be
   * triggered or, if there are no fallback intents defined, no intent will be triggered. The score
   * values range from 0.0 (completely uncertain) to 1.0 (completely certain). If set to 0.0, the
   * default of 0.3 is used.
   * @param classificationThreshold classificationThreshold or {@code null} for none
   */
  public GoogleCloudDialogflowV2Agent setClassificationThreshold(java.lang.Float classificationThreshold) {
    this.classificationThreshold = classificationThreshold;
    return this;
  }

  /**
   * Required. The default language of the agent as a language tag. See [Language
   * Support](https://cloud.google.com/dialogflow/docs/reference/language) for a list of the
   * currently supported language codes. This field cannot be set by the `Update` method.
   * @return value or {@code null} for none
   */
  public java.lang.String getDefaultLanguageCode() {
    return defaultLanguageCode;
  }

  /**
   * Required. The default language of the agent as a language tag. See [Language
   * Support](https://cloud.google.com/dialogflow/docs/reference/language) for a list of the
   * currently supported language codes. This field cannot be set by the `Update` method.
   * @param defaultLanguageCode defaultLanguageCode or {@code null} for none
   */
  public GoogleCloudDialogflowV2Agent setDefaultLanguageCode(java.lang.String defaultLanguageCode) {
    this.defaultLanguageCode = defaultLanguageCode;
    return this;
  }

  /**
   * Optional. The description of this agent. The maximum length is 500 characters. If exceeded, the
   * request is rejected.
   * @return value or {@code null} for none
   */
  public java.lang.String getDescription() {
    return description;
  }

  /**
   * Optional. The description of this agent. The maximum length is 500 characters. If exceeded, the
   * request is rejected.
   * @param description description or {@code null} for none
   */
  public GoogleCloudDialogflowV2Agent setDescription(java.lang.String description) {
    this.description = description;
    return this;
  }

  /**
   * Required. The name of this agent.
   * @return value or {@code null} for none
   */
  public java.lang.String getDisplayName() {
    return displayName;
  }

  /**
   * Required. The name of this agent.
   * @param displayName displayName or {@code null} for none
   */
  public GoogleCloudDialogflowV2Agent setDisplayName(java.lang.String displayName) {
    this.displayName = displayName;
    return this;
  }

  /**
   * Optional. Determines whether this agent should log conversation queries.
   * @return value or {@code null} for none
   */
  public java.lang.Boolean getEnableLogging() {
    return enableLogging;
  }

  /**
   * Optional. Determines whether this agent should log conversation queries.
   * @param enableLogging enableLogging or {@code null} for none
   */
  public GoogleCloudDialogflowV2Agent setEnableLogging(java.lang.Boolean enableLogging) {
    this.enableLogging = enableLogging;
    return this;
  }

  /**
   * Optional. Determines how intents are detected from user queries.
   * @return value or {@code null} for none
   */
  public java.lang.String getMatchMode() {
    return matchMode;
  }

  /**
   * Optional. Determines how intents are detected from user queries.
   * @param matchMode matchMode or {@code null} for none
   */
  public GoogleCloudDialogflowV2Agent setMatchMode(java.lang.String matchMode) {
    this.matchMode = matchMode;
    return this;
  }

  /**
   * Required. The project of this agent. Format: `projects/`.
   * @return value or {@code null} for none
   */
  public java.lang.String getParent() {
    return parent;
  }

  /**
   * Required. The project of this agent. Format: `projects/`.
   * @param parent parent or {@code null} for none
   */
  public GoogleCloudDialogflowV2Agent setParent(java.lang.String parent) {
    this.parent = parent;
    return this;
  }

  /**
   * Optional. The list of all languages supported by this agent (except for the
   * `default_language_code`).
   * @return value or {@code null} for none
   */
  public java.util.List<java.lang.String> getSupportedLanguageCodes() {
    return supportedLanguageCodes;
  }

  /**
   * Optional. The list of all languages supported by this agent (except for the
   * `default_language_code`).
   * @param supportedLanguageCodes supportedLanguageCodes or {@code null} for none
   */
  public GoogleCloudDialogflowV2Agent setSupportedLanguageCodes(java.util.List<java.lang.String> supportedLanguageCodes) {
    this.supportedLanguageCodes = supportedLanguageCodes;
    return this;
  }

  /**
   * Optional. The agent tier. If not specified, TIER_STANDARD is assumed.
   * @return value or {@code null} for none
   */
  public java.lang.String getTier() {
    return tier;
  }

  /**
   * Optional. The agent tier. If not specified, TIER_STANDARD is assumed.
   * @param tier tier or {@code null} for none
   */
  public GoogleCloudDialogflowV2Agent setTier(java.lang.String tier) {
    this.tier = tier;
    return this;
  }

  /**
   * Required. The time zone of this agent from the [time zone database](https://www.iana.org/time-
   * zones), e.g., America/New_York, Europe/Paris.
   * @return value or {@code null} for none
   */
  public java.lang.String getTimeZone() {
    return timeZone;
  }

  /**
   * Required. The time zone of this agent from the [time zone database](https://www.iana.org/time-
   * zones), e.g., America/New_York, Europe/Paris.
   * @param timeZone timeZone or {@code null} for none
   */
  public GoogleCloudDialogflowV2Agent setTimeZone(java.lang.String timeZone) {
    this.timeZone = timeZone;
    return this;
  }

  @Override
  public GoogleCloudDialogflowV2Agent set(String fieldName, Object value) {
    return (GoogleCloudDialogflowV2Agent) super.set(fieldName, value);
  }

  @Override
  public GoogleCloudDialogflowV2Agent clone() {
    return (GoogleCloudDialogflowV2Agent) super.clone();
  }

}
